/*-------------------------------------------------------------------------+
| Copyright 2023 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.ext.quality.data;

import java.util.HashMap;
import java.util.Map;

import org.fortiss.tooling.base.model.element.IHierarchicElement;
import org.fortiss.tooling.kernel.model.IProjectRootElement;

/**
 * 
 * @author groh
 */
public class MetricDataManager {

	/** a map to lookup the corresponding tree node */
	private Map<IHierarchicElement, MetricTreeNode> hierarchicLookupTable;

	/** the root tree node */
	private Map<IProjectRootElement, MetricTreeNode> root_nodes;

	/**
	 * Constructs a new instance of the MetricDataManager
	 */
	public MetricDataManager() {
		root_nodes = new HashMap<>();
		hierarchicLookupTable = new HashMap<>();
	}

	/**
	 * @return the lookup map
	 */
	public Map<IHierarchicElement, MetricTreeNode> getHierarchicLookupTable() {
		return hierarchicLookupTable;
	}

	/**
	 * @return a map containing all root nodes
	 */
	public Map<IProjectRootElement, MetricTreeNode> getRootNodes() {
		return root_nodes;
	}
}
