/*--------------------------------------------------------------------------+
|                                                                          |
| Copyright 2021 fortiss GmbH              							       |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.ext.variability.ui.editor;

import org.eclipse.jface.viewers.LabelProvider;
import org.fortiss.tooling.kernel.ui.presentation.ModelElementLabelProvider;
import org.fortiss.variability.model.features.AbstractFeature;
import org.fortiss.variability.model.features.configuration.IFeatureConfiguration;
import org.fortiss.variability.model.features.configuration.VariantConfiguration;

/**
 * {@link LabelProvider} for {@link VariantConfiguration} Trees.
 * 
 * @author bayha
 */
public class VariantConfigurationLabelProvider extends ModelElementLabelProvider {
	/** {@inheritDoc} */
	@Override
	public String getText(Object element) {
		if (element instanceof VariantConfiguration) {
			return ((VariantConfiguration) element).getName();
		}
		if (element instanceof IFeatureConfiguration) {
			IFeatureConfiguration<?> fcc = (IFeatureConfiguration<?>) element;
			final AbstractFeature referencedFeature = fcc.getFeatureReference();
			if(referencedFeature != null) {
				return referencedFeature.getName();
			}
			
			return "";
		}
		return super.getText(element);
	}
}
